@@ -1,4 +1,3 @@
-from __future__ import print_function
 """This module defines an ASE interface to FLAPW code FLEUR.
 
 http://www.flapw.de
@@ -502,7 +501,7 @@ class FLEUR:
 
         # total energies
         self.total_energies = []
-        pat = re.compile('(.*total energy=)(\s)*([-0-9.]*)')
+        pat = re.compile(r'(.*total energy=)(\s)*([-0-9.]*)')
         for line in lines:
             m = pat.match(line)
             if m:
@@ -511,7 +510,7 @@ class FLEUR:
 
         # free_energies
         self.free_energies = []
-        pat = re.compile('(.*free energy=)(\s)*([-0-9.]*)')
+        pat = re.compile(r'(.*free energy=)(\s)*([-0-9.]*)')
         for line in lines:
             m = pat.match(line)
             if m:
