@@ -1,4 +1,4 @@
-from __future__ import print_function
+# flake8: noqa
 #!/usr/bin/env python3
 
 '''
@@ -103,7 +103,7 @@ class SGROUP:
         for line in self.output:
             if regexp.search(line):
                 line = line[32:]
-                r2 = re.compile('^\d+')
+                r2 = re.compile(r'^\d+')
                 s = r2.search(line)
                 if hasattr(s,'group'):
                     return int(s.group())
