@@ -1,4 +1,4 @@
-from __future__ import print_function
+# flake8: noqa
 """ class Wannier provides the function get_wannier_localization_matrix and initial_wannier.
 """
 
