@@ -3,9 +3,7 @@
 
 Authors:
     Edward Tait, ewt23@cam.ac.uk
-
-Recent updates:
-    Nicholas Hine, n.d.m.hine@warwick.ac.uk
+    Nicholas Hine, n.d.m.hine@warwick.ac.uk (current maintainer)
 
     Based on castep.py by:
     Max Hoffmann, max.hoffmann@ch.tum.de
@@ -29,7 +27,7 @@ __all__ = ['Onetep']
 
 class Onetep(FileIOCalculator):
     """Implements the calculator for the onetep linear
-    scaling DFT code. Recomended ASE_ONETEP_COMMAND format
+    scaling DFT code. Recommended ASE_ONETEP_COMMAND format
     is "onetep_executable_name PREFIX.dat > PREFIX.out 2> PREFIX.err" """
 
     implemented_properties = ['energy', 'forces', 'dipole', 'magmom']
@@ -40,7 +38,10 @@ class Onetep(FileIOCalculator):
     # written elsewhere in the input file
     _dummy_parameters = ['ngwf_radius', 'xc', 'species_ngwf_radius',
                          'species_ngwf_number', 'species_solver',
-                         'ngwf_radius_cond', 'pseudo_suffix']
+                         'ngwf_radius_cond', 'pseudo_suffix',
+                         'species_pseudo', 'species_core_wf',
+                         'species_solver_cond', 'species_ngwf_number_cond',
+                         'species_ngwf_radius_cond']
 
     # Used to indicate which parameters are a kpoint path and should be
     # written as such
@@ -77,6 +78,9 @@ class Onetep(FileIOCalculator):
         self.species = []
         self.species_cond = []
         self.pseudos = []
+        self.core_wfs = []
+        self.solvers = []
+        self.solvers_cond = []
         self.restart = False
         self.prefix = label
         self.directory = '.'
@@ -113,14 +117,18 @@ class Onetep(FileIOCalculator):
                 read_lattice = True
             elif '%block species_pot' in clean_line:
                 self._read_species_pot(out)
-            elif '%block species' in clean_line:
+            elif clean_line.endswith('%block species_atomic_set'):
+                self._read_species_solver(out)
+            elif clean_line.endswith('%block species'):
                 self._read_species(out)
                 read_species = True
             elif '%block positions_abs' in clean_line:
                 self._read_positions(out)
                 read_positions = True
             elif '%block species_cond' in clean_line:
-                self._read_species_cond(out)
+                self._read_species(out,cond=True)
+            elif '%block species_atomic_set_cond' in clean_line:
+                self._read_species_solver(out,cond=True)
             elif 'warn' in line.lower():
                 warnings.append(line)
             line = out.readline()
@@ -137,10 +145,13 @@ class Onetep(FileIOCalculator):
 
         self.read_results(label)
 
-    def read_results(self):
+    def read_results(self,label=None):
         FileIOCalculator.read_results(self)
 
-        onetep_file = self.label + '.out'
+        if label is None:
+           onetep_file = self.label + '.out'
+        else:
+           onetep_file = label + '.out'
 
         warnings = []
 
@@ -160,6 +171,8 @@ class Onetep(FileIOCalculator):
                 self._read_geom_output(out)
             elif ('Integrated spin density' in line):
                 self.results['magmom'] = self._read_magmom(line)
+            elif '|Excitation|    Energy (in Ha)   |     Oscillator Str' in line:
+                self._read_excitations(out)
             elif ('Dipole Moment Calculation' in line):
                 self.results['dipole'] = self._read_dipole(out)
             elif 'warn' in line.lower():
@@ -225,7 +238,18 @@ class Onetep(FileIOCalculator):
                 symbols.append(atom)
                 positions.append(pos)
             line = out.readline()
+        tags = deepcopy(symbols)
+        for j in range(len(symbols)):
+            symbols[j] = ''.join(i for i in symbols[j] if not i.isdigit())
+        for j in range(len(tags)):
+            tags[j] = ''.join(i for i in tags[j] if not i.isalpha())
+            if tags[j]=='':
+               tags[j]='0'
+            tags[j] = int(tags[j])
+        if len(self.atoms)!=len(symbols):
+           self.atoms = Atoms(symbols=symbols,positions=positions)
         self.atoms.set_chemical_symbols(symbols)
+        self.atoms.set_tags(tags)
         self.atoms.set_positions(positions)
 
     def _read_dipole(self, out):
@@ -280,7 +304,7 @@ class Onetep(FileIOCalculator):
         self.atoms.set_positions(positions)
         self.atoms.set_chemical_symbols(symbols)
 
-    def _read_species(self, out):
+    def _read_species(self, out, cond=False):
         """ Read in species block from a onetep output file"""
         line = out.readline().strip()
         species = []
@@ -291,7 +315,10 @@ class Onetep(FileIOCalculator):
             ngwf_radius = float(ngwf_radius)
             species.append((atom, element, z, nngwf, ngwf_radius,))
             line = out.readline().strip()
-        self.set_species(species)
+        if not cond:
+            self.set_species(species)
+        else:
+            self.set_species_cond(species)
 
     def _read_species_pot(self, out):
         """ Read in pseudopotential information from a onetep output file"""
@@ -308,18 +335,21 @@ class Onetep(FileIOCalculator):
             raise ReadError('End of file while reading potential block')
         self.set_pseudos(pots)
 
-    def _read_species_cond(self, out):
-        """ Read in conduction species block from a onetep output file"""
+    def _read_species_solver(self, out, cond=False):
+        """ Read in pseudopotential information from a onetep output file"""
         line = out.readline().strip()
-        species_cond = []
-        while '%endblock' not in line.lower():
-            atom, element, z, nngwf, ngwf_radius = line.split(None, 5)
-            z = int(z)
-            nngwf = int(nngwf)
-            ngwf_radius = float(ngwf_radius)
-            species_cond.append((atom, element, z, nngwf, ngwf_radius, ))
+        solvers = []
+        while '%endblock' not in line.lower() and len(line) > 0:
+            atom, suffix = line.split(None, 1)
+            solver_str = suffix.split('#', 1)[0].strip()
+            solvers.append((atom, solver_str))
             line = out.readline().strip()
-        self.set_species_cond(species_cond)
+        if len(line) == 0:
+            raise ReadError('End of file while reading solver block')
+        if not cond:
+            self.set_solvers(solvers)
+        else:
+            self.set_solvers_cond(solvers)
 
     def _read_forces(self, out):
         """ Extract the computed forces from a onetep output file"""
@@ -337,6 +367,19 @@ class Onetep(FileIOCalculator):
             fields = line.split()
         self.results['forces'] = array(forces)
 
+    def _read_excitations(self,out):
+        """ Extract the computed electronic excitations from a onetep output
+        file."""
+        excitations = []
+        line = out.readline()
+        while line:
+            words = line.split()
+            if len(words)==0:
+                break
+            excitations.append([float(words[0]),float(words[1])*Hartree,float(words[2])])
+            line = out.readline()
+        self.results['excitations'] = array(excitations)
+
     def _generate_species_block(self, cond=False):
         """Create a default onetep species block, use -1 for the NGWF number
         to trigger automatic NGWF number assigment using onetep's internal
@@ -360,7 +403,8 @@ class Onetep(FileIOCalculator):
             species_ngwf_rad_var = 'species_ngwf_radius_cond'
             species_ngwf_num_var = 'species_ngwf_number_cond'
         for sp in set(zip(atoms.get_atomic_numbers(),
-                          atoms.get_chemical_symbols())):
+                          atoms.get_chemical_symbols(),
+                          ["" if i==0 else str(i) for i in atoms.get_tags()])):
             try:
                 ngrad = parameters[species_ngwf_rad_var][sp[1]]
             except KeyError:
@@ -370,23 +414,78 @@ class Onetep(FileIOCalculator):
             except KeyError:
                 ngnum = -1
             if not cond:
-                self.species.append((sp[1], sp[1], sp[0], ngnum, ngrad))
+                self.species.append((sp[1]+sp[2], sp[1], sp[0], ngnum, ngrad))
             else:
-                self.species_cond.append((sp[1], sp[1], sp[0], ngnum, ngrad))
+                self.species_cond.append((sp[1]+sp[2], sp[1], sp[0], ngnum, ngrad))
 
     def _generate_pseudo_block(self):
+        """Create a default onetep pseudopotentials block, using the
+        element name with the variable pseudo_suffix appended to it by default,
+        unless the user has set overrides for specific species by setting
+        specific entries in species_pseudo"""
 
         for sp in self.species:
-            self.pseudos.append((sp[1], sp[1] +
-                                 self.parameters['pseudo_suffix']))
+            try:
+                pseudo_string = self.parameters['species_pseudo'][sp[0]]
+            except KeyError:
+                try:
+                    pseudo_string = sp[1] + self.parameters['pseudo_suffix']
+                except KeyError:
+                    pseudo_string = sp[1] # bare elem name if pseudo suffix empty
+            self.pseudos.append((sp[0], pseudo_string))
+
+    def _generate_solver_block(self,cond=False):
+        """Create a default onetep pseudoatomic solvers block, using 'SOLVE'
+        unless the user has set overrides for specific species by setting
+        specific entries in species_solver (_cond)"""
+
+        if not cond:
+            solver_var = 'species_solver'
+        else:
+            solver_var = 'species_solver_cond'
+        for sp in self.species:
+            try:
+                atomic_string = self.parameters[solver_var][sp[0]]
+            except KeyError:
+                atomic_string = 'SOLVE'
+            if not cond:
+                self.solvers.append((sp[0], atomic_string))
+            else:
+                self.solvers_cond.append((sp[0],atomic_string))
+
+    def _generate_core_wf_block(self):
+        """Create a default onetep core wavefunctions block, using 'NONE'
+        unless the user has set overrides for specific species by setting
+        specific entries in species_core_wf. If all are NONE, no block
+        will be printed"""
+
+        any_core_wfs = False
+        for sp in self.species:
+            try:
+                core_wf_string = self.parameters['species_core_wf'][sp[0]]
+                any_core_wfs = True
+            except KeyError:
+                core_wf_string = 'NONE'
+
+            self.core_wfs.append((sp[0], core_wf_string))
+
+        # if no species core wavefunction definitions were set to anything
+        # other than 'NONE', delete the block entirely
+        if not any_core_wfs:
+            self.core_wfs = []
 
     def set_pseudos(self, pots):
-        """ Sets the pseudopotential files used in this dat file
-        TODO: add some verification - do the pseudos imply the same
-        functional as we're using?"""
-
+        """ Sets the pseudopotential files used in this dat file """
         self.pseudos = deepcopy(pots)
 
+    def set_solvers(self, solvers):
+        """ Sets the solver strings used in this dat file """
+        self.solvers = deepcopy(solvers)
+
+    def set_solvers_cond(self, solvers):
+        """ Sets the solver strings used in this dat file """
+        self.solvers_cond = deepcopy(solvers)
+
     def set_atoms(self, atoms):
         self.atoms = atoms
 
@@ -418,13 +517,23 @@ class Onetep(FileIOCalculator):
             self.parameters['read_denskern'] = True
 
         self._generate_species_block()
-        if 'ngwf_radius_cond' in self.parameters:
-            self._generate_species_block(cond=True)
 
         if len(self.pseudos) < len(self.species):
             if 'pseudo_suffix' in self.parameters:
                 self._generate_pseudo_block()
 
+        if len(self.solvers) < len(self.species):
+            self._generate_solver_block()
+
+        if 'ngwf_radius_cond' in self.parameters:
+            if len(self.species_cond) < len(self.species):
+                self._generate_species_block(cond=True)
+            if len(self.solvers_cond) < len(self.species):
+                self._generate_solver_block(cond=True)
+
+        if len(self.core_wfs) < len(self.species):
+            self._generate_core_wf_block()
+
         self._write_dat()
 
     def get_dipole_moment(self, atoms=None):
@@ -462,19 +571,19 @@ class Onetep(FileIOCalculator):
         fd.write('#ONETEP .dat file: %s\n' % filename)
         fd.write('#Created using the Atomic Simulation Environment (ASE)\n')
         fd.write('######################################################\n\n')
+
         fd.write('%BLOCK LATTICE_CART\n')
         fd.write('ang\n')
-
         for line in atoms.get_cell():
             fd.write('    %.10f %.10f %.10f\n' % tuple(line))
         fd.write('%ENDBLOCK LATTICE_CART\n\n\n')
 
         keyword = 'POSITIONS_ABS'
-
         positions = atoms.get_positions()
+        tags = ["" if i==0 else str(i) for i in atoms.get_tags()]
         pos_block = [('%s %8.6f %8.6f %8.6f' %
-                      (x, y[0], y[1], y[2])) for (x, y)
-                     in zip(atoms.get_chemical_symbols(), positions)]
+                      (x+z, y[0], y[1], y[2])) for (x, y, z)
+                     in zip(atoms.get_chemical_symbols(), positions, tags)]
 
         fd.write('%%BLOCK %s\n' % keyword)
         fd.write('ang\n')
@@ -483,45 +592,51 @@ class Onetep(FileIOCalculator):
         fd.write('%%ENDBLOCK %s\n\n' % keyword)
 
         keyword = 'SPECIES'
-
         sp_block = [('%s %s %d %d %8.6f' % sp) for sp in self.species]
-
         fd.write('%%BLOCK %s\n' % keyword)
-        for line in sp_block:
+        for line in sorted(sp_block):
             fd.write('    %s\n' % line)
         fd.write('%%ENDBLOCK %s\n\n' % keyword)
 
-        if (self.parameters['ngwf_radius_cond'] > 0):
+        if ((self.parameters['ngwf_radius_cond'] > 0) or
+            len(self.species_cond)==len(self.species)):
             keyword = 'SPECIES_COND'
-
             sp_block = [('%s %s %d %d %8.6f' % sp) for sp in self.species_cond]
-
             fd.write('%%BLOCK %s\n' % keyword)
-            for line in sp_block:
+            for line in sorted(sp_block):
                 fd.write('    %s\n' % line)
             fd.write('%%ENDBLOCK %s\n\n' % keyword)
 
         keyword = 'SPECIES_POT'
         fd.write('%%BLOCK %s\n' % keyword)
-        for sp in self.pseudos:
+        for sp in sorted(self.pseudos):
             fd.write('    %s "%s"\n' % (sp[0], sp[1]))
         fd.write('%%ENDBLOCK %s\n\n' % keyword)
 
         keyword = 'SPECIES_ATOMIC_SET'
         fd.write('%%BLOCK %s\n' % keyword)
-        for sym in set(self.atoms.get_chemical_symbols()):
-            try:
-                atomic_string = parameters['species_solver'][sym]
-            except KeyError:
-                atomic_string = 'SOLVE'
-
-            fd.write('    %s "%s"\n' % (sym, atomic_string))
+        for sp in sorted(self.solvers):
+            fd.write('    %s "%s"\n' % (sp[0], sp[1]))
         fd.write('%%ENDBLOCK %s\n\n' % keyword)
 
+        if ((self.parameters['ngwf_radius_cond'] > 0) or
+            len(self.solvers_cond)==len(self.species)):
+            keyword = 'SPECIES_ATOMIC_SET_COND'
+            fd.write('%%BLOCK %s\n' % keyword)
+            for sp in sorted(self.solvers_cond):
+                fd.write('    %s "%s"\n' % (sp[0], sp[1]))
+            fd.write('%%ENDBLOCK %s\n\n' % keyword)
+
+        if self.core_wfs:
+            keyword = 'SPECIES_CORE_WF'
+            fd.write('%%BLOCK %s\n' % keyword)
+            for sp in sorted(self.core_wfs):
+                fd.write('    %s "%s"\n' % (sp[0], sp[1]))
+            fd.write('%%ENDBLOCK %s\n\n' % keyword)
+
         if 'bsunfld_calculate' in self.parameters:
             if 'species_bsunfld_groups' not in self.parameters:
-                self.parameters['species_bsunfld_groups'] = \
-                    str(set(self.atoms.get_chemical_symbols()))
+                self.parameters['species_bsunfld_groups'] = self.atoms.get_chemical_symbols()
 
         # Loop over parameters entries in alphabetal order, outputting
         # them as keywords or blocks as appropriate
