@@ -1,3 +1,4 @@
+# flake8: noqa
 # -*- coding: utf-8 -*-
 
 """Infrared and Raman intensities using siesta and MBPT_LCAO"""
@@ -73,7 +74,7 @@ class SiestaRaman(Vibrations):
         use the dipole moment in all directions.
 
     freq_pol: float or array of float
-        frequency at which the Raman intensity is computed, can be float or array 
+        frequency at which the Raman intensity is computed, can be float or array
 
     Example:
 
@@ -114,7 +115,7 @@ class SiestaRaman(Vibrations):
     def __init__(self, atoms, siesta, indices=None, name='ram',
                  delta=0.01, nfree=2, directions=None, freq_pol=0.0, **kw):
 
-        Vibrations.__init__(self, atoms, indices=indices, name=name, 
+        Vibrations.__init__(self, atoms, indices=indices, name=name,
                             delta = delta, nfree=nfree)
         if atoms.constraints:
             warnings.warn('WARNING! \n Your Atoms object is constrained. ' +
@@ -186,10 +187,10 @@ class SiestaRaman(Vibrations):
                 [fplus, dplus, frplus, noninpplus, pplus] = pickle.load(
                     open(name + '+.pckl', "rb"))
                 if self.nfree == 4:
-                    [fminusminus, dminusminus, frminusminus, 
+                    [fminusminus, dminusminus, frminusminus,
                             noninpminusminus, pminusminus] =\
                                     pickle.load(open(name + '--.pckl', "rb"))
-                    [fplusplus, dplusplus, frplusplus, 
+                    [fplusplus, dplusplus, frplusplus,
                             noninpplusplus, pplusplus] =\
                                     pickle.load(open(name + '++.pckl', "rb"))
                 if self.method == 'frederiksen':
@@ -321,7 +322,7 @@ class SiestaRaman(Vibrations):
         iu_ir, iu_string_ir = self.intensity_prefactor(intensity_unit_ir)
         iu_ram, iu_string_ram = self.intensity_prefactor(intensity_unit_ram)
         arr = []
- 
+
         freq_idx = (np.abs(self.freq_pol-freq_pol)).argmin()
         print("index: ", freq_idx)
 
@@ -392,7 +393,7 @@ class SiestaRaman(Vibrations):
         s = 0.01 * units._e / units._c / units._hplanck
         iu_ir, iu_string_ir = self.intensity_prefactor(intensity_unit_ir)
         iu_ram, iu_string_ram = self.intensity_prefactor(intensity_unit_ram)
- 
+
         freq_idx = (np.abs(self.freq_pol-freq_pol)).argmin()
 
 
@@ -431,18 +432,18 @@ class SiestaRaman(Vibrations):
                 column = column + "c"
 
         f = open(fname, 'w')
-        f.write("\begin{table}[h] \n")
-        f.write("  \caption{" + caption + "} \n")
-        f.write("  \begin{center}\n")
-        f.write("    \begin{tabular}{" + column + "} \n")
+        f.write("\\begin{table}[h] \n")
+        f.write("  \\caption{" + caption + "} \n")
+        f.write("  \\begin{center}\n")
+        f.write("    \\begin{tabular}{" + column + "} \n")
 
         if hline:
-            f.write("     \hline \n")
+            f.write("     \\hline \n")
 
         f.write('     Mode & Frequency (meV) & Frequency ($cm^{-1}$) & Intensity IR  (' +
                 iu_string_ir + ')  & Intensity Raman (' + iu_string_ram + ') \n')
         if hline:
-            f.write("   \hline \n")
+            f.write("   \\hline \n")
         for n, e in enumerate(hnu):
             if e.imag != 0:
                 c = ' + i'
@@ -456,10 +457,10 @@ class SiestaRaman(Vibrations):
                                                         self.intensities_ram[n, freq_idx].real))
             if hline:
                 f.write(r"      \hline \n")
-        f.write("    \end{tabular} \n")
-        f.write("  \end{center} \n")
-        f.write(" \label{" + label + "} \n")
-        f.write("\end{table}\n")
+        f.write("    \\end{tabular} \n")
+        f.write("  \\end{center} \n")
+        f.write(" \\label{" + label + "} \n")
+        f.write("\\end{table}\n")
 
         f.close()
 
@@ -478,7 +479,7 @@ class SiestaRaman(Vibrations):
         name = '%s.eq.pckl' % self.name
         [forces_zero, dipole_zero, freq_zero, noninPol_zero,
             pol_zero] = pickle.load(open(name, "rb"))
- 
+
         freq_idx = (np.abs(self.freq_pol-freq_pol)).argmin()
 
         frequencies = self.get_frequencies(method, direction).real
