@@ -1,4 +1,3 @@
-from __future__ import print_function
 import os
 
 from ase.io import read, write
@@ -49,6 +48,14 @@ class CLICommand:
             help='Write output frames to individual files. '
             'Output file name should be a format string with '
             'a single integer field, e.g. out-{:0>5}.xyz')
+        add('--read-args', nargs='+', action='store', 
+            default={}, metavar="KEY=VALUE",
+            help='Additional keyword arguments to pass to '
+            '`ase.io.read()`.')
+        add('--write-args', nargs='+', action='store', 
+            default={}, metavar="KEY=VALUE",
+            help='Additional keyword arguments to pass to '
+            '`ase.io.write()`.')
 
     @staticmethod
     def run(args, parser):
@@ -62,10 +69,15 @@ class CLICommand:
             args.info = [k.strip() for k in args.info.split(',')]
             if args.verbose:
                 print('Filtering to include info: ', ', '.join(args.info))
+        if args.read_args:
+            args.read_args = eval("dict({0})".format(', '.join(args.read_args)))
+        if args.write_args:
+            args.write_args = eval("dict({0})".format(', '.join(args.write_args)))
 
         configs = []
         for filename in args.input:
-            atoms = read(filename, args.image_number, format=args.input_format)
+            atoms = read(filename, args.image_number, 
+                         format=args.input_format, **args.read_args)
             if isinstance(atoms, list):
                 configs.extend(atoms)
             else:
@@ -91,6 +103,7 @@ class CLICommand:
 
         if args.split_output:
             for i, atoms in enumerate(configs):
-                write(args.output.format(i), atoms, format=args.output_format)
+                write(args.output.format(i), atoms, 
+                      format=args.output_format, **args.write_args)
         else:
-            write(args.output, configs, format=args.output_format)
+            write(args.output, configs, format=args.output_format, **args.write_args)
