@@ -1,3 +1,4 @@
+# flake8: noqa
 """Minimum mode follower for finding saddle points in an unbiased way.
 
 There is, currently, only one implemented method: The Dimer method.
@@ -12,7 +13,7 @@ import numpy as np
 
 from ase.optimize.optimize import Optimizer
 from math import cos, sin, atan, tan, degrees, pi, sqrt
-from ase.parallel import rank, size, world
+from ase.parallel import world
 from ase.calculators.singlepoint import SinglePointCalculator
 from ase.utils import basestring
 
@@ -328,7 +329,7 @@ class MinModeControl:
     def initialize_logfiles(self, logfile=None, eigenmode_logfile=None):
         """Set up the log files."""
         # Set up the regular logfile
-        if rank != 0:
+        if world.rank != 0:
             logfile = None
         elif isinstance(logfile, basestring):
             if logfile == '-':
@@ -339,7 +340,7 @@ class MinModeControl:
 
         # Set up the eigenmode logfile
         if eigenmode_logfile:
-            if rank != 0:
+            if world.rank != 0:
                 eigenmode_logfile = None
             elif isinstance(eigenmode_logfile, basestring):
                 if eigenmode_logfile == '-':
@@ -561,8 +562,8 @@ class MinModeAtoms:
         # Seed the randomness
         if random_seed is None:
             t = time.time()
-            if size > 1:
-                t = world.sum(t) / float(size)
+            if world.size > 1:
+                t = world.sum(t) / world.size
             # Harvest the latter part of the current time
             random_seed = int(('%30.9f' % t)[-9:])
         self.random_state = np.random.RandomState(random_seed)
