@@ -210,10 +210,17 @@ def get_rdf(atoms, rmax, nbins, distance_matrix=None,
     and the corresponding distances of the supplied atoms object.
     If no_dists = True then only the first array is returned.
 
+    Note that the rdf is computed following the standard solid state
+    definition which uses the cell volume in the normalization.
+    This may or may not be appropriate in cases where one or more
+    directions is non-periodic.
+
     Parameters:
 
     rmax : float
         The maximum distance that will contribute to the rdf.
+        The unit cell should be large enough so that it encloses a
+        sphere with radius rmax in the periodic directions.
 
     nbins : int
         Number of bins to divide the rdf into.
@@ -230,15 +237,26 @@ def get_rdf(atoms, rmax, nbins, distance_matrix=None,
     no_dists : bool
         If True then the second array with rdf distances will not be returned
     """
+    # First check whether the cell is sufficiently large
+    cell = atoms.get_cell()
+    vol = atoms.get_volume()
+    pbc = atoms.get_pbc()
+    for i in range(3):
+        if pbc[i]:
+            axb = np.cross(cell[(i + 1) % 3, :], cell[(i + 2) % 3, :])
+            h = vol / np.linalg.norm(axb)
+            assert h > 2 * rmax, 'The cell is not large enough in ' \
+                 'direction %d: %.3f < 2*rmax=%.3f' % (i, h, 2 * rmax)
+
     dm = distance_matrix
     if dm is None:
-        dm = atoms.get_all_distances()
+        dm = atoms.get_all_distances(mic=True)
     rdf = np.zeros(nbins + 1)
     dr = float(rmax / nbins)
 
     if elements is None:
         # Coefficients to use for normalization
-        phi = len(atoms) / atoms.get_volume()
+        phi = len(atoms) / vol
         norm = 2.0 * math.pi * dr * phi * len(atoms)
 
         for i in range(len(atoms)):
@@ -249,7 +267,7 @@ def get_rdf(atoms, rmax, nbins, distance_matrix=None,
                     rdf[index] += 1
     else:
         i_indices = np.where(atoms.numbers == elements[0])[0]
-        phi = len(i_indices) / atoms.get_volume()
+        phi = len(i_indices) / vol
         norm = 4.0 * math.pi * dr * phi * len(atoms)
 
         for i in i_indices:
