@@ -5,7 +5,7 @@ from ase.geometry.cell import (cell_to_cellpar, cellpar_to_cell,
 from ase.geometry.geometry import (wrap_positions,
                                    get_layers, find_mic,
                                    get_duplicate_atoms,
-                                   get_angles, get_distances)
+                                   get_angles, get_distances, permute_axes)
 from ase.geometry.distance import distance
 from ase.geometry.minkowski_reduction import minkowski_reduce
 
@@ -14,4 +14,5 @@ __all__ = ['Cell', 'wrap_positions', 'complete_cell',
            'get_layers', 'find_mic', 'get_duplicate_atoms',
            'cell_to_cellpar', 'cellpar_to_cell',
            'crystal_structure_from_cell', 'distance',
-           'get_angles', 'get_distances', 'minkowski_reduce']
+           'get_angles', 'get_distances', 'minkowski_reduce',
+           'permute_axes']
