@@ -1,6 +1,5 @@
 # -*- coding: utf-8 -*-
 """colors.py - select how to color the atoms in the GUI."""
-from __future__ import unicode_literals
 from ase.gui.i18n import _
 
 import numpy as np
@@ -117,10 +116,10 @@ class ColorWindow:
             rng = mx - mn  # XXX what are optimal allowed range and steps ?
             self.mnmx = [_('min:'),
                          ui.SpinBox(mn, mn - 10 * rng, mx + rng, rng / 10.,
-                                    self.change_mnmx),
+                                    self.change_mnmx, width=20),
                          _('max:'),
                          ui.SpinBox(mx, mn - 10 * rng, mx + rng, rng / 10.,
-                                    self.change_mnmx),
+                                    self.change_mnmx, width=20),
                          _(unit)]
             self.win.close()
             self.reset(self.gui)
