@@ -1,5 +1,3 @@
-from __future__ import unicode_literals, division
-
 import os
 import pickle
 import subprocess
@@ -123,6 +121,14 @@ class GUI(View, Status):
         if self.movie_window is not None:
             self.movie_window.frame_number.value = i + 1
 
+    def copy_image(self, key=None):
+        self.images._images.append(self.atoms.copy())
+        self.images.filenames.append(None)
+
+        if self.movie_window is not None:
+            self.movie_window.frame_number.scale.configure(to=len(self.images))
+        self.step('End')
+
     def _do_zoom(self, x):
         """Utility method for zooming"""
         self.scale *= x
@@ -444,7 +450,8 @@ class GUI(View, Status):
               M(_('_First image'), self.step, 'Home'),
               M(_('_Previous image'), self.step, 'Page-Up'),
               M(_('_Next image'), self.step, 'Page-Down'),
-              M(_('_Last image'), self.step, 'End')]),
+              M(_('_Last image'), self.step, 'End'),
+              M(_('Append image copy'), self.copy_image)]),
 
             (_('_View'),
              [M(_('Show _unit cell'), self.toggle_show_unit_cell, 'Ctrl+U',
@@ -501,8 +508,9 @@ class GUI(View, Status):
               M(_('Expert mode ...'), self.execute, disabled=True),
               M(_('Constraints ...'), self.constraints_window),
               M(_('Render scene ...'), self.render_window),
-              M(_('_Move atoms'), self.toggle_move_mode, 'Ctrl+M'),
-              M(_('_Rotate atoms'), self.toggle_rotate_mode, 'Ctrl+R'),
+              M(_('_Move selected atoms'), self.toggle_move_mode, 'Ctrl+M'),
+              M(_('_Rotate selected atoms'), self.toggle_rotate_mode,
+                'Ctrl+R'),
               M(_('NE_B'), self.neb),
               M(_('B_ulk Modulus'), self.bulk_modulus),
               M(_('Reciprocal space ...'), self.reciprocal)]),
