@@ -1,14 +1,10 @@
-from __future__ import print_function
 import pickle
 import sys
 
 
 def main():
     import matplotlib.pyplot as plt
-    stdin = sys.stdin
-    if sys.version_info[0] == 3:
-        stdin = stdin.buffer
-    task, data = pickle.load(stdin)
+    task, data = pickle.load(sys.stdin.buffer)
     if task == 'eos':
         from ase.eos import plot
         plot(*data)
