@@ -1,32 +1,20 @@
-from __future__ import unicode_literals
-try:
-    # Python 3
-    import tkinter as tk
-    import tkinter.ttk as ttk
-    from tkinter.messagebox import askokcancel as ask_question
-    from tkinter.messagebox import showerror, showwarning, showinfo
-    from tkinter.filedialog import LoadFileDialog, SaveFileDialog
-except ImportError:
-    # Python 2
-    import Tkinter as tk
-    try:
-        import ttk
-    except ImportError:
-        ttk = None
-    from tkMessageBox import (askokcancel as ask_question, showerror,
-                              showwarning, showinfo)
-    from FileDialog import LoadFileDialog, SaveFileDialog
 
 import re
 import sys
 from collections import namedtuple
 from functools import partial
-from ase.gui.i18n import _
 
 import numpy as np
+import tkinter as tk
+import tkinter.ttk as ttk
+from tkinter.messagebox import askokcancel as ask_question
+from tkinter.messagebox import showerror, showwarning, showinfo
+from tkinter.filedialog import LoadFileDialog, SaveFileDialog
 
+from ase.gui.i18n import _
 from ase.utils import basestring
 
+
 __all__ = [
     'error', 'ask_question', 'MainWindow', 'LoadFileDialog', 'SaveFileDialog',
     'ASEGUIWindow', 'Button', 'CheckButton', 'ComboBox', 'Entry', 'Label',
