@@ -2,8 +2,8 @@ from ase.visualize.plot import animate
 
 
 def write_animation(filename, images, writer=None,
-                    interval=200, save_count=100, show_unit_cell=2,
-                    save_parameters=None, **kwargs):
+                    interval=200, save_count=100,
+                    save_parameters=None, ax=None, **kwargs):
     import matplotlib.pyplot as plt
 
     if writer is None and filename.endswith('.gif'):
@@ -13,11 +13,11 @@ def write_animation(filename, images, writer=None,
     if save_parameters is None:
         save_parameters = {}
 
-    fig = plt.figure()
-    ax = fig.add_subplot(111)
-    animation = animate(images, fig=fig, ax=ax,
+    if ax is None:
+        ax = plt.gca()
+
+    animation = animate(images, ax=ax,
                         interval=interval, save_count=save_count,
-                        show_unit_cell=show_unit_cell,
                         **kwargs)
     animation.save(filename, writer=writer,
                    **save_parameters)
