@@ -1,4 +1,3 @@
-from __future__ import print_function
 """bundletrajectory - a module for I/O from large MD simulations.
 
 The BundleTrajectory class writes trajectory into a directory with the
@@ -18,8 +17,7 @@ following structure::
         F1 (dir)
 """
 
-import ase.parallel
-from ase.parallel import paropen
+from ase.parallel import paropen, world, barrier
 from ase.calculators.singlepoint import (SinglePointCalculator,
                                          PropertyNotImplementedError)
 from ase.io.ulm import open as ulmopen
@@ -30,6 +28,8 @@ import shutil
 import time
 # The system json module causes memory leaks!  Use ase's own.
 # import json
+
+from ase import Atoms
 from ase.io import jsonio
 try:
     import cPickle as pickle   # Need efficient pickle if using Python 2
@@ -88,7 +88,7 @@ class BundleTrajectory:
         self.filename = filename
         self.pre_observers = []  # callback functions before write is performed
         self.post_observers = []  # callback functions after write is performed
-        self.master = ase.parallel.rank == 0
+        self.master = world.rank == 0
         self.extra_data = []
         self.singleprecision = singleprecision
         self._set_defaults()
@@ -169,8 +169,7 @@ class BundleTrajectory:
         # Write 'small' data structures.  They are written jointly.
         smalldata = {'pbc': atoms.get_pbc(),
                      'cell': atoms.get_cell(),
-                     # GLOBAL number of atoms:
-                     'natoms': atoms.get_number_of_atoms(),
+                     'natoms': atoms.get_global_number_of_atoms(),
                      'constraints': atoms.constraints}
         if datatypes.get('energy'):
             try:
@@ -348,7 +347,7 @@ class BundleTrajectory:
             self.atom_id, dummy = self.backend.read_split(framedir, 'ID')
         else:
             self.atom_id = None
-        atoms = ase.Atoms(**data)
+        atoms = Atoms(**data)
         natoms = smalldata['natoms']
         for name in ('positions', 'numbers', 'tags', 'masses',
                      'momenta'):
@@ -423,7 +422,7 @@ class BundleTrajectory:
             lfn = os.path.join(self.filename, 'log.txt')
         else:
             lfn = os.path.join(self.filename, ('log-node%d.txt' %
-                                               (ase.parallel.rank,)))
+                                               (world.rank,)))
         self.logfile = open(lfn, 'a', 1)   # Append to log if it exists.
         if hasattr(self, 'logdata'):
             for text in self.logdata:
@@ -438,33 +437,33 @@ class BundleTrajectory:
         self.atoms = atoms
         if os.path.exists(self.filename):
             # The output directory already exists.
-            ase.parallel.barrier()  # all must have time to see it exists
+            barrier()  # all must have time to see it exists
             if not self.is_bundle(self.filename, allowempty=True):
                 raise IOError(
                     'Filename "' + self.filename +
                     '" already exists, but is not a BundleTrajectory.' +
                     'Cowardly refusing to remove it.')
             if self.is_empty_bundle(self.filename):
-                ase.parallel.barrier()
+                barrier()
                 self.log('Deleting old "%s" as it is empty' % (self.filename,))
                 self.delete_bundle(self.filename)
             elif not backup:
-                ase.parallel.barrier()
+                barrier()
                 self.log('Deleting old "%s" as backup is turned off.' %
                          (self.filename,))
                 self.delete_bundle(self.filename)
             else:
-                ase.parallel.barrier()
+                barrier()
                 # Make a backup file
                 bakname = self.filename + '.bak'
                 if os.path.exists(bakname):
-                    ase.parallel.barrier()  # All must see it exists
+                    barrier()  # All must see it exists
                     self.log('Deleting old backup file "%s"' % (bakname,))
                     self.delete_bundle(bakname)
                 self.log('Renaming "%s" to "%s"' % (self.filename, bakname))
                 self._rename_bundle(self.filename, bakname)
         # Ready to create a new bundle.
-        ase.parallel.barrier()
+        barrier()
         self.log('Creating new "%s"' % (self.filename,))
         self._make_bundledir(self.filename)
         self.state = 'prewrite'
@@ -505,14 +504,13 @@ class BundleTrajectory:
             self.pythonmajor = 2  # Assume written with Python 2.
         # We need to know if we are running Python 3.X and try to read
         # a bundle written with Python 2.X
-        self.backend.readpy2 = (sys.version_info[0] >= 3 and
-                                self.pythonmajor == 2)
+        self.backend.readpy2 = (self.pythonmajor == 2)
         self.state = 'read'
 
     def _open_append(self, atoms):
         if not os.path.exists(self.filename):
             # OK, no old bundle.  Open as for write instead.
-            ase.parallel.barrier()
+            barrier()
             self._open_write(atoms, False)
             return
         if not self.is_bundle(self.filename):
@@ -598,7 +596,7 @@ class BundleTrajectory:
     def is_bundle(filename, allowempty=False):
         """Check if a filename exists and is a BundleTrajectory.
 
-        If allowempty=True, an empty folder is regarded as an 
+        If allowempty=True, an empty folder is regarded as an
         empty BundleTrajectory."""
         if not os.path.isdir(filename):
             return False
@@ -634,13 +632,13 @@ class BundleTrajectory:
         f.close()
 
         # File may be removed by the master immediately after this.
-        ase.parallel.barrier()
+        barrier()
         return nframes == 0
 
     @classmethod
     def delete_bundle(cls, filename):
         "Deletes a bundle."
-        if ase.parallel.rank == 0:
+        if world.rank == 0:
             # Only the master deletes
             if not cls.is_bundle(filename, allowempty=True):
                 raise IOError(
@@ -659,7 +657,7 @@ class BundleTrajectory:
         # The master may not proceed before all tasks have seen the
         # directory go away, as it might otherwise create a new bundle
         # with the same name, fooling the wait loop in _make_bundledir.
-        ase.parallel.barrier()
+        barrier()
 
     def _rename_bundle(self, oldname, newname):
         "Rename a bundle.  Used to create the .bak"
@@ -670,7 +668,7 @@ class BundleTrajectory:
                 time.sleep(1)
         # The master may not proceed before all tasks have seen the
         # directory go away.
-        ase.parallel.barrier()
+        barrier()
 
     def _make_bundledir(self, filename):
         """Make the main bundle directory.
@@ -680,7 +678,7 @@ class BundleTrajectory:
         """
         self.log('Making directory ' + filename)
         assert not os.path.isdir(filename)
-        ase.parallel.barrier()
+        barrier()
         if self.master:
             os.mkdir(filename)
         else:
