@@ -11,7 +11,6 @@ description of the Extended XYZ file format.
 Contributed by James Kermode <james.kermode@gmail.com>
 """
 
-from __future__ import print_function
 
 from itertools import islice
 import re
@@ -332,11 +331,11 @@ def parse_properties(prop_str):
 
 def _read_xyz_frame(lines, natoms, properties_parser=key_val_str_to_dict, nvec=0):
     # comment line
-    line = next(lines)
+    line = next(lines).strip()
     if nvec > 0:
-        info = {'comment': line.strip()}
+        info = {'comment': line}
     else:
-        info = properties_parser(line)
+        info = properties_parser(line) if line else {}
 
     pbc = None
     if 'pbc' in info:
@@ -628,13 +627,13 @@ def output_column_format(atoms, columns, arrays,
     """
     Helper function to build extended XYZ comment line
     """
-    fmt_map = {'d': ('R', '%16.8f '),
-               'f': ('R', '%16.8f '),
-               'i': ('I', '%8d '),
-               'O': ('S', '%s '),
-               'S': ('S', '%s '),
-               'U': ('S', '%s '),
-               'b': ('L', ' %.1s ')}
+    fmt_map = {'d': ('R', '%16.8f'),
+               'f': ('R', '%16.8f'),
+               'i': ('I', '%8d'),
+               'O': ('S', '%s'),
+               'S': ('S', '%s'),
+               'U': ('S', '%-2s'),
+               'b': ('L', ' %.1s')}
 
     # NB: Lattice is stored as tranpose of ASE cell,
     # with Fortran array ordering
@@ -689,7 +688,7 @@ def output_column_format(atoms, columns, arrays,
     comment_str += ' ' + key_val_dict_to_str(info, tolerant=tolerant)
 
     dtype = np.dtype(dtypes)
-    fmt = ''.join(formats) + '\n'
+    fmt = ' '.join(formats) + '\n'
 
     return comment_str, property_ncols, dtype, fmt
 
