@@ -202,6 +202,21 @@ def read_lammps_data(fileobj, Z_of_type=None, style="full",
                             int(fields[7]),
                             int(fields[8]),
                         )
+                if style == "charge" and (len(fields) == 6 or len(fields) == 9):
+                    # id type q x y z [tx ty tz]
+                    pos_in[id] = (
+                        int(fields[1]),
+                        float(fields[3]),
+                        float(fields[4]),
+                        float(fields[5]),
+                    )
+                    charge_in[id] = float(fields[2])
+                    if len(fields) == 9:
+                        travel_in[id] = (
+                            int(fields[6]),
+                            int(fields[7]),
+                            int(fields[8]),
+                        )
                 else:
                     raise RuntimeError(
                         "Style '{}' not supported or invalid "
@@ -394,15 +409,20 @@ def read_lammps_data(fileobj, Z_of_type=None, style="full",
 def write_lammps_data(fileobj, atoms, specorder=None, force_skew=False,
                       prismobj=None, velocities=False, units="metal",
                       atom_style='atomic'):
-    """Write atomic structure data to a LAMMPS data_ file."""
+    """Write atomic structure data to a LAMMPS data file."""
     if isinstance(fileobj, basestring):
-        f = paropen(fileobj, "wb")
+        f = paropen(fileobj, "w", encoding="ascii")
         close_file = True
     else:
         # Presume fileobj acts like a fileobj
         f = fileobj
         close_file = False
 
+    # FIXME: We should add a check here that the encoding of the file object
+    #        is actually ascii once the 'encoding' attribute of IOFormat objects
+    #        starts functioning in implementation (currently it doesn't do
+    #         anything).
+
     if isinstance(atoms, list):
         if len(atoms) > 1:
             raise ValueError(
@@ -410,11 +430,11 @@ def write_lammps_data(fileobj, atoms, specorder=None, force_skew=False,
             )
         atoms = atoms[0]
 
-    f.write("{0} (written by ASE) \n\n".format(f.name).encode("utf-8"))
+    f.write("{0} (written by ASE) \n\n".format(f.name))
 
     symbols = atoms.get_chemical_symbols()
     n_atoms = len(symbols)
-    f.write("{0} \t atoms \n".format(n_atoms).encode("utf-8"))
+    f.write("{0} \t atoms \n".format(n_atoms))
 
     if specorder is None:
         # This way it is assured that LAMMPS atom types are always
@@ -425,7 +445,7 @@ def write_lammps_data(fileobj, atoms, specorder=None, force_skew=False,
         # (indices must correspond to order in the potential file)
         species = specorder
     n_atom_types = len(species)
-    f.write("{0}  atom types\n".format(n_atom_types).encode("utf-8"))
+    f.write("{0}  atom types\n".format(n_atom_types))
 
     if prismobj is None:
         p = Prism(atoms.get_cell())
@@ -436,19 +456,19 @@ def write_lammps_data(fileobj, atoms, specorder=None, force_skew=False,
     xhi, yhi, zhi, xy, xz, yz = convert(p.get_lammps_prism(), "distance",
             "ASE", units)
 
-    f.write("0.0 {0:23.17g}  xlo xhi\n".format(xhi).encode("utf-8"))
-    f.write("0.0 {0:23.17g}  ylo yhi\n".format(yhi).encode("utf-8"))
-    f.write("0.0 {0:23.17g}  zlo zhi\n".format(zhi).encode("utf-8"))
+    f.write("0.0 {0:23.17g}  xlo xhi\n".format(xhi))
+    f.write("0.0 {0:23.17g}  ylo yhi\n".format(yhi))
+    f.write("0.0 {0:23.17g}  zlo zhi\n".format(zhi))
 
     if force_skew or p.is_skewed():
         f.write(
             "{0:23.17g} {1:23.17g} {2:23.17g}  xy xz yz\n".format(
                 xy, xz, yz
-            ).encode("utf-8")
+            )
         )
-    f.write("\n\n".encode("utf-8"))
+    f.write("\n\n")
 
-    f.write("Atoms \n\n".encode("utf-8"))
+    f.write("Atoms \n\n")
     pos = p.vector_to_lammps(atoms.get_positions(), wrap=True)
 
     if atom_style == 'atomic':
@@ -459,7 +479,7 @@ def write_lammps_data(fileobj, atoms, specorder=None, force_skew=False,
             f.write(
                 "{0:>6} {1:>3} {2:23.17g} {3:23.17g} {4:23.17g}\n".format(
                     *(i + 1, s) + tuple(r)
-                ).encode("utf-8")
+                )
             )
     elif atom_style == 'charge':
         charges = atoms.get_initial_charges()
@@ -471,7 +491,7 @@ def write_lammps_data(fileobj, atoms, specorder=None, force_skew=False,
             f.write(
                 "{0:>6} {1:>3} {2:>5} {3:23.17g} {4:23.17g} {5:23.17g}\n".format(
                     *(i + 1, s, q) + tuple(r)
-                ).encode("utf-8")
+                )
             )
     elif atom_style == 'full':
         charges = atoms.get_initial_charges()
@@ -482,15 +502,15 @@ def write_lammps_data(fileobj, atoms, specorder=None, force_skew=False,
             q = convert(q, "charge", "ASE", units)
             s = species.index(symbols[i]) + 1
             f.write(
-                "{0:>6} {1>3} {2:>3} {3:>5} {4:23.17g} {5:23.17g} {6:23.17g}\n".format(
+                "{0:>6} {1:>3} {2:>3} {3:>5} {4:23.17g} {5:23.17g} {6:23.17g}\n".format(
                     *(i + 1, molecule, s, q) + tuple(r)
-                ).encode("utf-8")
+                )
             )
     else:
         raise NotImplementedError
 
     if velocities and atoms.get_velocities() is not None:
-        f.write("\n\nVelocities \n\n".encode("utf-8"))
+        f.write("\n\nVelocities \n\n")
         vel = p.vector_to_lammps(atoms.get_velocities())
         for i, v in enumerate(vel):
             # Convert velocity from ASE units to LAMMPS units
@@ -498,7 +518,7 @@ def write_lammps_data(fileobj, atoms, specorder=None, force_skew=False,
             f.write(
                 "{0:>6} {1:23.17g} {2:23.17g} {3:23.17g}\n".format(
                     *(i + 1,) + tuple(v)
-                ).encode("utf-8")
+                )
             )
 
     f.flush()
