@@ -12,6 +12,14 @@ from collections import OrderedDict
 import ase.units
 from ase.atoms import Atoms
 from ase.spacegroup import Spacegroup
+from ase.calculators.singlepoint import SinglePointDFTCalculator
+
+_mprops = {
+    'ms': ('sigma', 1),
+    'sus': ('S', 0),
+    'efg': ('V', 1),
+    'isc': ('K', 2)}
+# (matrix name, number of atoms in interaction) for various magres quantities
 
 
 def read_magres(fd, include_unrecognised=False):
@@ -123,6 +131,10 @@ def read_magres(fd, include_unrecognised=False):
 
         name, records = block
 
+        # 3x3 tensor
+        def ntensor33(name):
+            return lambda d: {name: tensor33([float(x) for x in data])}
+
         # Atom label, atom index and 3x3 tensor
         def sitensor33(name):
             return lambda d: {'atom': {'label': data[0],
@@ -138,6 +150,7 @@ def read_magres(fd, include_unrecognised=False):
                               name: tensor33([float(x) for x in data[4:]])}
 
         tags = {'ms': sitensor33('sigma'),
+                'sus': ntensor33('S'),
                 'efg': sitensor33('V'),
                 'efg_local': sitensor33('V'),
                 'efg_nonlocal': sitensor33('V'),
@@ -321,30 +334,20 @@ def read_magres(fd, include_unrecognised=False):
 
     # Now for the magres specific stuff
     li_list = list(zip(labels, indices))
-    mprops = {
-        'ms': ('sigma', False),
-        'efg': ('V', False),
-        'isc': ('K', True)}
-    # (matrix name, is pair interaction) for various magres quantities
 
-    def create_magres_array(u, block):
+    def create_magres_array(name, order, block):
 
-        # This bit to keep track of tags
-        u0 = u.split('_')[0]
-        if u0 not in mprops:
-            raise RuntimeError('Invalid data in magres block')
-
-        mn = mprops[u0][0]
-        is_pair = mprops[u0][1]
-
-        if not is_pair:
+        if order == 1:
             u_arr = [None] * len(li_list)
-        else:
+        elif order == 2:
             u_arr = [[None] * (i + 1) for i in range(len(li_list))]
+        else:
+            raise ValueError(
+                'Invalid order value passed to create_magres_array')
 
         for s in block:
             # Find the atom index/indices
-            if not is_pair:
+            if order == 1:
                 # First find out which atom this is
                 at = (s['atom']['label'], s['atom']['index'])
                 try:
@@ -368,8 +371,28 @@ def read_magres(fd, include_unrecognised=False):
         if 'units' in data_dict['magres']:
             atoms.info['magres_units'] = dict(data_dict['magres']['units'])
             for u in atoms.info['magres_units']:
-                u_arr = create_magres_array(u, data_dict['magres'][u])
-                atoms.new_array(u, u_arr)
+                # This bit to keep track of tags
+                u0 = u.split('_')[0]
+
+                if u0 not in _mprops:
+                    raise RuntimeError('Invalid data in magres block')
+
+                mn, order = _mprops[u0]
+
+                if order > 0:
+                    u_arr = create_magres_array(mn, order,
+                                                data_dict['magres'][u])
+                    atoms.new_array(u, u_arr)
+                else:
+                    # atoms.info['magres_data'] = atoms.info.get('magres_data',
+                    #                                            {})
+                    # # We only take element 0 because for this sort of data
+                    # # there should be only that
+                    # atoms.info['magres_data'][u] = data_dict['magres'][u][0][mn]
+                    if atoms.calc is None:
+                        calc = SinglePointDFTCalculator(atoms)
+                        atoms.set_calculator(calc)
+                        atoms.calc.results[u] = data_dict['magres'][u][0][mn]
 
     if 'calculation' in data_dict:
         atoms.info['magresblock_calculation'] = data_dict['calculation']
@@ -438,37 +461,41 @@ def write_magres(fd, image):
     if 'magres_units' in image.info:
 
         image_data['magres'] = {'units': []}
-        mprops = {
-            'ms': ('sigma', False),
-            'efg': ('V', False),
-            'isc': ('K', True)}
 
         for u in image.info['magres_units']:
             # Get the type
             p = u.split('_')[0]
-            if p in mprops:
+            if p in _mprops:
                 image_data['magres']['units'].append(
                     [u, image.info['magres_units'][u]])
                 image_data['magres'][u] = []
-                prop = mprops[p]
-                arr = image.get_array(u)
-                li_tab = zip(labels, indices)
-                for i, (lab, ind) in enumerate(li_tab):
-                    if prop[1]:
-                        for j, (lab2, ind2) in enumerate(li_tab[:i + 1]):
-                            if arr[i][j] is not None:
-                                tens = {prop[0]: arr[i][j],
-                                        'atom1': {'label': lab,
-                                                  'index': ind},
-                                        'atom2': {'label': lab2,
-                                                  'index': ind2}}
-                                image_data['magres'][u].append(tens)
-                    else:
-                        if arr[i] is not None:
-                            tens = {prop[0]: arr[i],
-                                    'atom': {'label': lab,
-                                             'index': ind}}
-                            image_data['magres'][u].append(tens)
+                mn, order = _mprops[p]
+
+                if order == 0:
+                    # The case of susceptibility
+                    tens = {
+                        mn: image.calc.results[u]
+                    }
+                    image_data['magres'][u] = tens
+                else:
+                    arr = image.get_array(u)
+                    li_tab = zip(labels, indices)
+                    for i, (lab, ind) in enumerate(li_tab):
+                        if order == 2:
+                            for j, (lab2, ind2) in enumerate(li_tab[:i + 1]):
+                                if arr[i][j] is not None:
+                                    tens = {mn: arr[i][j],
+                                            'atom1': {'label': lab,
+                                                      'index': ind},
+                                            'atom2': {'label': lab2,
+                                                      'index': ind2}}
+                                    image_data['magres'][u].append(tens)
+                        elif order == 1:
+                            if arr[i] is not None:
+                                tens = {mn: arr[i],
+                                        'atom': {'label': lab,
+                                                 'index': ind}}
+                                image_data['magres'][u].append(tens)                
 
     # Calculation block, if present
     if 'magresblock_calculation' in image.info:
@@ -486,6 +513,11 @@ def write_magres(fd, image):
 
         out = []
 
+        def nout(tag, tensor_name):
+            if tag in data:
+                out.append(('  %s %s') % (tag, 
+                                          tensor_string(data[tag][tensor_name])))
+
         def siout(tag, tensor_name):
             if tag in data:
                 for atom_si in data[tag]:
@@ -497,6 +529,7 @@ def write_magres(fd, image):
 
         write_units(data, out)
 
+        nout('sus', 'S')
         siout('ms', 'sigma')
 
         siout('efg_local', 'V')
