@@ -1,4 +1,4 @@
-from __future__ import division
+# flake8: noqa
 from abc import abstractmethod, ABC
 import functools
 import warnings
@@ -7,6 +7,7 @@ import numpy as np
 from ase.cell import Cell
 from ase.build.bulk import bulk as newbulk
 from ase.dft.kpoints import parse_path_string, sc_special_points, BandPath
+from ase.utils import pbc2pbc
 
 
 @functools.wraps(newbulk)
@@ -1046,7 +1047,7 @@ class CRECT(BravaisLattice):
         return points
 
 
-@bravaisclass('primitive square', 'tetragonal', None, 'tp', ('a'),
+@bravaisclass('primitive square', 'tetragonal', None, 'tp', ('a',),
               [['SQR', 'GMX', 'MGXM',
                 get_subset_points('GMX', sc_special_points['tetragonal'])]],
               ndim=2)
@@ -1060,6 +1061,19 @@ class SQR(BravaisLattice):
                          [0, 0, 0.]])
 
 
+@bravaisclass('primitive line', 'line', None, '?', ('a',),
+              [['LINE', 'GX', 'GX', {'G': [0, 0, 0], 'X': [0.5, 0, 0]}]],
+              ndim=1)
+class LINE(BravaisLattice):
+    def __init__(self, a, **kwargs):
+        BravaisLattice.__init__(self, a=a, **kwargs)
+
+    def _cell(self, a):
+        return np.array([[a, 0.0, 0.0],
+                         [0.0, 0.0, 0.0],
+                         [0.0, 0.0, 0.0]])
+
+
 def celldiff(cell1, cell2):
     """Return a unitless measure of the difference between two cells."""
     cell1 = Cell.ascell(cell1).complete()
@@ -1085,32 +1099,46 @@ def get_lattice_from_canonical_cell(cell, eps=2e-4):
     return LatticeChecker(cell, eps).match()
 
 
-def identify_lattice(cell, eps=2e-4, *, pbc=None):
+def identify_lattice(cell, eps=2e-4, *, pbc=True):
     """Find Bravais lattice representing this cell.
 
     Returns Bravais lattice object representing the cell along with
-    and operation that, applied to the cell, yields the same lengths
+    an operation that, applied to the cell, yields the same lengths
     and angles as the Bravais lattice object."""
 
-    if pbc is None:
-        pbc = cell.any(1)
-
+    pbc = cell.any(1) & pbc2pbc(pbc)
     npbc = sum(pbc)
+
+    if npbc == 1:
+        i = np.argmax(pbc)  # index of periodic axis
+        a = cell[i, i]
+        if a < 0 or cell[i, [i - 1, i - 2]].any():
+            raise ValueError('Not a 1-d cell ASE can handle: {cell}.'
+                             .format(cell=cell))
+        if i == 0:
+            op = np.eye(3)
+        elif i == 1:
+            op = np.array([[0, 1, 0], [1, 0, 0], [0, 0, 1]])
+        else:
+            op = np.array([[0, 0, 1], [0, 1, 0], [1, 0, 0]])
+        return LINE(a), op
+
     if npbc == 2:
         lat, op = get_2d_bravais_lattice(cell, eps, pbc=pbc)
         return lat, op
 
     if npbc != 3:
-        raise ValueError('System must be periodic either along two first '
-                         'axes or along all three.  Got pbc={}'
-                         .format(pbc))
-
+        raise ValueError('System must be periodic either '
+                         'along all three axes, '
+                         'along two first axes or, '
+                         'along the thrid axis.  '
+                         'Got pbc={}'.format(pbc))
 
     from ase.geometry.bravais_type_engine import niggli_op_table
 
     if cell.rank < 3:
         raise ValueError('Expected 3 linearly independent cell vectors')
-    rcell, reduction_op = cell.niggli_reduce()
+    rcell, reduction_op = cell.niggli_reduce(eps=eps)
 
     # We tabulate the cell's Niggli-mapped versions so we don't need to
     # redo any work when the same Niggli-operation appears multiple times
@@ -1323,11 +1351,9 @@ class UnsupportedLattice(ValueError):
     pass
 
 
-def get_2d_bravais_lattice(origcell, eps=2e-4, *, pbc=None):
-    if pbc is None:
-        pbc = origcell.any(1)
-    pbc = np.asarray(pbc, bool)
+def get_2d_bravais_lattice(origcell, eps=2e-4, *, pbc=True):
 
+    pbc = origcell.any(1) & pbc2pbc(pbc)
     if list(pbc) != [1, 1, 0]:
         raise UnsupportedLattice('Can only get 2D Bravais lattice of cell with '
                                  'pbc==[1, 1, 0]; but we have {}'.format(pbc))
@@ -1396,7 +1422,7 @@ def get_2d_bravais_lattice(origcell, eps=2e-4, *, pbc=None):
     return finallat, finalop.T
 
 
-def all_variants():
+def all_variants(include_blunt_angles=True):
     """For testing and examples; yield all variants of all lattices."""
     a, b, c = 3., 4., 5.
     alpha = 55.0
@@ -1484,3 +1510,9 @@ def all_variants():
     yield CRECT(a, alpha=alpha)
     yield HEX2D(a)
     yield SQR(a)
+    yield LINE(a)
+
+    if include_blunt_angles:
+        beta = 110
+        yield OBL(a, b, alpha=beta)
+        yield CRECT(a, alpha=beta)
