@@ -1,4 +1,4 @@
-from __future__ import print_function
+# flake8: noqa
 """Bravais.py - class for generating Bravais lattices etc.
 
 This is a base class for numerous classes setting up pieces of crystal.
