@@ -1,10 +1,12 @@
-from math import sqrt
-
 import numpy as np
+import itertools
 from scipy import sparse as sp
+from scipy.spatial import cKDTree
 
 from ase.data import atomic_numbers, covalent_radii
-from ase.geometry import complete_cell
+from ase.geometry import complete_cell, find_mic, wrap_positions
+from ase.geometry import minkowski_reduce
+from ase.cell import Cell
 
 
 def natural_cutoffs(atoms, mult=1, **kwargs):
@@ -111,7 +113,7 @@ def get_distance_indices(distanceMatrix, distance):
 
 
 
-def mic(dr, cell, pbc=None):
+def mic(dr, cell, pbc=True):
     """
     Apply minimum image convention to an array of distance vectors.
 
@@ -131,15 +133,8 @@ def mic(dr, cell, pbc=None):
         Array of distance vectors, wrapped according to the minimum image
         convention.
     """
-    # Check where distance larger than 1/2 cell. Particles have crossed
-    # periodic boundaries then and need to be unwrapped.
-    icell = np.linalg.pinv(cell)
-    if pbc is not None:
-        icell *= np.array(pbc, dtype=int).reshape(3, 1)
-    cell_shift_vectors = np.round(np.dot(dr, icell))
-
-    # Unwrap
-    return dr - np.dot(cell_shift_vectors, cell)
+    dr, _ = find_mic(dr, cell, pbc)
+    return dr
 
 
 def primitive_neighbor_list(quantities, pbc, cell, positions, cutoff,
@@ -844,7 +839,6 @@ class NewPrimitiveNeighborList:
                 self.offset_vec[self.first_neigh[a]:self.first_neigh[a+1]])
 
 
-
 class PrimitiveNeighborList:
     """Neighbor list that works without Atoms objects.
 
@@ -885,7 +879,7 @@ class PrimitiveNeighborList:
         to self.use_scaled_positions.
         """
         self.pbc = pbc = np.array(pbc, copy=True)
-        self.cell = cell = np.array(cell, copy=True)
+        self.cell = cell = Cell(cell)
         self.coordinates = coordinates = np.array(coordinates, copy=True)
 
         if len(self.cutoffs) != len(coordinates):
@@ -897,61 +891,69 @@ class PrimitiveNeighborList:
         else:
             rcmax = 0.0
 
-        icell = np.linalg.pinv(cell)
-
         if self.use_scaled_positions:
-            scaled = coordinates
-            positions = np.dot(scaled, cell)
+            positions0 = cell.cartesian_positions(coordinates)
         else:
-            positions = coordinates
-            scaled = np.dot(positions, icell)
+            positions0 = coordinates
 
-        scaled0 = scaled.copy()
+        rcell, op = minkowski_reduce(cell, pbc)
+        positions = wrap_positions(positions0, rcell, pbc=pbc, eps=0)
+
+        natoms = len(positions)
+        self.nneighbors = 0
+        self.npbcneighbors = 0
+        self.neighbors = [np.empty(0, int) for a in range(natoms)]
+        self.displacements = [np.empty((0, 3), int) for a in range(natoms)]
+        self.nupdates += 1
+        if natoms == 0:
+            return
 
         N = []
+        ircell = np.linalg.pinv(rcell)
         for i in range(3):
             if self.pbc[i]:
-                scaled0[:, i] %= 1.0
-                v = icell[:, i]
-                h = 1 / sqrt(np.dot(v, v))
+                v = ircell[:, i]
+                h = 1 / np.linalg.norm(v)
                 n = int(2 * rcmax / h) + 1
             else:
                 n = 0
             N.append(n)
 
-        offsets = (scaled0 - scaled).round().astype(int)
-        positions0 = positions + np.dot(offsets, self.cell)
-        natoms = len(positions)
-        indices = np.arange(natoms)
+        tree = cKDTree(positions, copy_data=True)
+        offsets = cell.scaled_positions(positions - positions0)
+        offsets = offsets.round().astype(np.int)
 
-        self.nneighbors = 0
-        self.npbcneighbors = 0
-        self.neighbors = [np.empty(0, int) for a in range(natoms)]
-        self.displacements = [np.empty((0, 3), int) for a in range(natoms)]
-        for n1 in range(0, N[0] + 1):
-            for n2 in range(-N[1], N[1] + 1):
-                for n3 in range(-N[2], N[2] + 1):
-                    if n1 == 0 and (n2 < 0 or n2 == 0 and n3 < 0):
-                        continue
-                    displacement = np.dot((n1, n2, n3), self.cell)
-                    for a in range(natoms):
-                        d = positions0 + displacement - positions0[a]
-                        i = indices[(d**2).sum(1) <
-                                    (self.cutoffs + self.cutoffs[a])**2]
-                        if n1 == 0 and n2 == 0 and n3 == 0:
-                            if self.self_interaction:
-                                i = i[i >= a]
-                            else:
-                                i = i[i > a]
-                        self.nneighbors += len(i)
-                        self.neighbors[a] = np.concatenate(
-                            (self.neighbors[a], i))
-                        disp = np.empty((len(i), 3), int)
-                        disp[:] = (n1, n2, n3)
-                        disp += offsets[i] - offsets[a]
-                        self.npbcneighbors += disp.any(1).sum()
-                        self.displacements[a] = np.concatenate(
-                            (self.displacements[a], disp))
+        for n1, n2, n3 in itertools.product(range(0, N[0] + 1),
+                                            range(-N[1], N[1] + 1),
+                                            range(-N[2], N[2] + 1)):
+            if n1 == 0 and (n2 < 0 or n2 == 0 and n3 < 0):
+                continue
+
+            displacement = (n1, n2, n3) @ rcell
+            for a in range(natoms):
+
+                indices = tree.query_ball_point(positions[a] - displacement,
+                                                r=self.cutoffs[a] + rcmax)
+                if not len(indices):
+                    continue
+
+                indices = np.array(indices)
+                delta = positions[indices] + displacement - positions[a]
+                cutoffs = self.cutoffs[indices] + self.cutoffs[a]
+                i = indices[np.linalg.norm(delta, axis=1) < cutoffs]
+                if n1 == 0 and n2 == 0 and n3 == 0:
+                    if self.self_interaction:
+                        i = i[i >= a]
+                    else:
+                        i = i[i > a]
+
+                self.nneighbors += len(i)
+                self.neighbors[a] = np.concatenate((self.neighbors[a], i))
+
+                disp = (n1, n2, n3) @ op + offsets[i] - offsets[a]
+                self.npbcneighbors += disp.any(1).sum()
+                self.displacements[a] = np.concatenate((self.displacements[a],
+                                                        disp))
 
         if self.bothways:
             neighbors2 = [[] for a in range(natoms)]
@@ -962,8 +964,7 @@ class PrimitiveNeighborList:
                     displacements2[b].append(-disp)
             for a in range(natoms):
                 nbs = np.concatenate((self.neighbors[a], neighbors2[a]))
-                disp = np.array(list(self.displacements[a]) +
-                                displacements2[a])
+                disp = np.array(list(self.displacements[a]) + displacements2[a])
                 # Force correct type and shape for case of no neighbors:
                 self.neighbors[a] = nbs.astype(int)
                 self.displacements[a] = disp.astype(int).reshape((-1, 3))
@@ -975,16 +976,12 @@ class PrimitiveNeighborList:
                     j = i[mask]
                     offsets = self.displacements[a][mask]
                     for b, offset in zip(j, offsets):
-                        self.neighbors[b] = np.concatenate(
-                            (self.neighbors[b], [a]))
-                        self.displacements[b] = np.concatenate(
-                            (self.displacements[b], [-offset]))
+                        self.neighbors[b] = np.concatenate((self.neighbors[b], [a]))
+                        self.displacements[b] = np.concatenate((self.displacements[b], [-offset]))
                     mask = np.logical_not(mask)
                     self.neighbors[a] = self.neighbors[a][mask]
                     self.displacements[a] = self.displacements[a][mask]
 
-        self.nupdates += 1
-
     def get_neighbors(self, a):
         """Return neighbors of atom number a.
 
@@ -994,7 +991,7 @@ class PrimitiveNeighborList:
 
           indices, offsets = nl.get_neighbors(42)
           for i, offset in zip(indices, offsets):
-              print(atoms.positions[i] + dot(offset, atoms.get_cell()))
+              print(atoms.positions[i] + offset @ atoms.get_cell())
 
         Notice that if get_neighbors(a) gives atom b as a neighbor,
         then get_neighbors(b) will not return a as a neighbor - unless
