@@ -1,4 +1,4 @@
-from __future__ import print_function
+# flake8: noqa
 # Copyright (C) 2003  CAMP
 # Please see the accompanying LICENSE file for further information.
 
