@@ -1,4 +1,3 @@
-from __future__ import print_function
 # Copyright (C) 2010, Jesper Friis
 # (see accompanying license files for details).
 
@@ -179,12 +178,17 @@ def crystal(symbols=None, basis=None, occupancies=None, spacegroup=1, setting=1,
     atoms = ase.Atoms(symbols,
                       scaled_positions=sites,
                       cell=cell,
-                      # use tags to identify sites, and in particular the occupancy
-                      tags=kinds,
                       pbc=pbc,
                       masses=masses,
                       **kwargs)
 
+    #  if all occupancies are 1, no partial occupancy present
+    if occupancies:
+        if not all([occ == 1 for occ in occupancies]):
+            # use tags to identify sites, and in particular the occupancy
+            atoms.set_tags(kinds)
+
+
     if isinstance(basis, ase.Atoms):
         for name in basis.arrays:
             if not atoms.has(name):
