@@ -1,7 +1,5 @@
 """Read and write json from/to file descriptor."""
-import sys
-from io import StringIO, BytesIO
-
+from io import StringIO
 from ase.io import read, write
 
 s = u"""
@@ -15,10 +13,7 @@ fd = StringIO(s)
 a = read(fd, format='json')
 assert a.get_chemical_formula() == 'H2'
 
-if sys.version_info[0] == 2:
-    fd = BytesIO()
-else:
-    fd = StringIO()
+fd = StringIO()
 write(fd, a, format='json')
 
 fd.seek(0)
