@@ -1,15 +1,13 @@
+import doctest
+import importlib
+import shutil
 import sys
 from unittest import SkipTest
 
-
 if sys.version_info < (3, 6):
     raise SkipTest('Test requires Python 3.6+, this is {}'
                    .format(sys.version_info))
 
-
-import doctest
-import importlib
-
 module_names = """\
 ase.atoms
 ase.build.tools
@@ -28,7 +26,9 @@ ase.spacegroup.xtal
 ase.symbols
 """
 
-
 for modname in module_names.splitlines():
+    if modname == 'ase.spacegroup.findsym' and not shutil.which('findsym'):
+        print('Skipping {} because we do not have findsym'.format(modname))
+        continue
     mod = importlib.import_module(modname)
     print(mod, doctest.testmod(mod, raise_on_error=True))
