@@ -1,11 +1,12 @@
+import unittest
 from matplotlib.animation import writers
-from ase.test.testsuite import NotAvailable
-from ase.build import bulk, molecule, fcc111
-from ase.io.animation import write_animation
 import warnings
 
+from ase.build import bulk, molecule, fcc111
+from ase.io.animation import write_animation
+
 if 'html' not in writers.list():
-    raise NotAvailable('matplotlib html writer not present')
+    raise unittest.SkipTest('matplotlib html writer not present')
 
 
 images = [molecule('H2O'), bulk('Cu'), fcc111('Au', size=(1, 1, 1))]
