@@ -1,5 +1,5 @@
 import numpy as np
-from ase.io.ulm import open
+import ase.io.ulm as ulm
 
 
 class A:
@@ -13,7 +13,7 @@ class A:
         return a
 
 
-w = open('a.ulm', 'w')
+w = ulm.open('a.ulm', 'w')
 w.write(a=A(), y=9)
 w.write(s='abc')
 w.sync()
@@ -23,7 +23,7 @@ w.write(s='abc3', z=np.ones(7, int))
 w.close()
 print(w.data)
 
-r = open('a.ulm')
+r = ulm.open('a.ulm')
 print(r.y, r.s)
 print(A.read(r.a).x)
 print(r.a.x)
@@ -31,16 +31,16 @@ print(r[1].s)
 print(r[2].s)
 print(r[2].z)
 
-w = open('a.ulm', 'a')
-print(w.nitems, w.offsets)
-w.write(d={'h': [1, 'asdf']})
-w.add_array('psi', (4, 3))
-w.fill(np.ones((1, 3)))
-w.fill(np.ones((1, 3)) * 2)
-w.fill(np.ones((2, 3)) * 3)
-w.close()
-print(open('a.ulm', 'r', 3).d)
-print(open('a.ulm')[2].z)
-print(open('a.ulm', index=3).proxy('psi')[0:3])
-for d in open('a.ulm'):
+with ulm.open('a.ulm', 'a') as w:
+    print(w.nitems, w.offsets)
+    w.write(d={'h': [1, 'asdf']})
+    w.add_array('psi', (4, 3))
+    w.fill(np.ones((1, 3)))
+    w.fill(np.ones((1, 3)) * 2)
+    w.fill(np.ones((2, 3)) * 3)
+
+print(ulm.open('a.ulm', 'r', 3).d)
+print(ulm.open('a.ulm')[2].z)
+print(ulm.open('a.ulm', index=3).proxy('psi')[0:3])
+for d in ulm.open('a.ulm'):
     print(d)
