@@ -1,11 +1,12 @@
+import sys
 import numpy as np
 from ase import Atoms
 from ase.formula import Formula
 
-
 assert Atoms('MoS2').get_chemical_formula() == 'MoS2'
 assert Atoms('SnO2').get_chemical_formula(mode='metal') == 'SnO2'
-
+if sys.version_info >= (3, 6):
+    assert Formula('A3B2C2D').format('abc') == 'DB2C2A3'
 
 for sym in ['', 'Pu', 'Pu2', 'U2Pu2', 'U2((Pu2)2H)']:
     for mode in ['all', 'reduce', 'hill', 'metal']:
@@ -24,7 +25,6 @@ for sym in ['', 'Pu', 'Pu2', 'U2Pu2', 'U2((Pu2)2H)']:
                 n2 = np.repeat(n2, reduction)
             assert (n1 == n2).all()
 
-
 for x in ['H2O', '10H2O', '2(CuO2(H2O)2)10', 'Cu20+H2', 'H' * 15,
           'AuBC2', '']:
     f = Formula(x)
