@@ -1,7 +1,7 @@
 from ase.calculators.lammpsrun import LAMMPS
 from ase.cluster.icosahedron import Icosahedron
 from ase.data import atomic_numbers,  atomic_masses
-from numpy.linalg import norm
+from numpy.testing import assert_allclose
 
 ar_nc = Icosahedron('Ar', noshells=2)
 ar_nc.cell = [[300, 0, 0], [0, 300, 0], [0, 0, 300]]
@@ -15,14 +15,12 @@ params['masses'] = ['1 {}'.format(atomic_masses[atomic_numbers['Ar']])]
 calc = LAMMPS(specorder=['Ar'], **params)
 
 ar_nc.set_calculator(calc)
+F1_numer = calc.calculate_numerical_forces(ar_nc)
 
-E = ar_nc.get_potential_energy()
-F = ar_nc.get_forces()
-
-assert abs(E - -0.47) < 1E-2
-assert abs(norm(F) - 0.0574) < 1E-4
-assert abs(norm(ar_nc.positions) - 23.588) < 1E-3
-
+assert_allclose(ar_nc.get_potential_energy(), -0.468147667942117,
+                atol=1e-4, rtol=1e-4)
+assert_allclose(ar_nc.get_forces(), calc.calculate_numerical_forces(ar_nc),
+                atol=1e-4, rtol=1e-4)
 
 params['minimize'] = '1.0e-15 1.0e-6 2000 4000'   # add minimize
 calc.parameters = params
@@ -33,9 +31,7 @@ calc.run(set_atoms=True)
 # get final coordinates after minimization
 ar_nc.set_positions(calc.atoms.positions)
 
-E = ar_nc.get_potential_energy()
-F = ar_nc.get_forces()
-
-assert abs(E - -0.48) < 1E-2
-assert abs(norm(F) - 0.0) < 1E-6
-assert abs(norm(ar_nc.positions) - 23.399) < 1E-3
+assert_allclose(ar_nc.get_potential_energy(), -0.4791815887032201,
+                atol=1e-4, rtol=1e-4)
+assert_allclose(ar_nc.get_forces(), calc.calculate_numerical_forces(ar_nc),
+                atol=1e-4, rtol=1e-4)
