@@ -3,6 +3,7 @@ from ase.spacegroup import crystal
 from ase.data import atomic_numbers,  atomic_masses
 from ase.optimize import QuasiNewton
 from ase.constraints import UnitCellFilter
+from numpy.testing import assert_allclose
 
 
 a = 6.15
@@ -19,7 +20,7 @@ pair_coeff = ['1 1 3796.9 0.2603 124.90']
 pair_coeff += ['2 2 1227.2 0.3214 124.90']
 pair_coeff += ['1 2 4117.9 0.3048 0.0']
 masses = ['1 {}'.format(atomic_masses[atomic_numbers['Na']]),
-        '2 {}'.format(atomic_masses[atomic_numbers['Cl']])]
+          '2 {}'.format(atomic_masses[atomic_numbers['Cl']])]
 
 calc = LAMMPS(specorder=['Na', 'Cl'],
               pair_style=pair_style,
@@ -28,7 +29,7 @@ calc = LAMMPS(specorder=['Na', 'Cl'],
               atom_style='charge',
               kspace_style='pppm 1.0e-5',
               keep_tmp_files=True,
-)
+              )
 
 for a in nacl:
     if a.symbol == 'Na':
@@ -38,12 +39,14 @@ for a in nacl:
 
 nacl.set_calculator(calc)
 
+assert_allclose(nacl.get_potential_energy(), -1896.216737561538,
+                atol=1e-4, rtol=1e-4)
+
 E = nacl.get_potential_energy()
 
 ucf = UnitCellFilter(nacl)
 dyn = QuasiNewton(ucf, force_consistent=False)
 dyn.run(fmax=1.0E-2)
 
-E = nacl.get_potential_energy()
-assert abs(E - -1897.208862) < 1E-2
-
+assert_allclose(nacl.get_potential_energy(), -1897.208861729178,
+                atol=1e-4, rtol=1e-4)
