@@ -5,21 +5,16 @@ environment variables
 
 """
 
-import unittest
 from ase.test.vasp import installed2 as installed
 from ase import Atoms
 from ase.calculators.vasp import Vasp2 as Vasp
 from ase.io import read
 import numpy as np
-import sys
 
 assert installed()
 
 
 def main():
-    if sys.version_info < (2, 7):
-        raise unittest.SkipTest('read_xml requires Python version 2.7 or greater')
-
     assert installed()
 
     # simple test calculation of CO molecule
