@@ -8,4 +8,4 @@ del a.constraints
 a *= (2, 1, 1)
 a.set_cell(images[0].get_cell())
 write('diffusion-path.pov', a, rotation='-90x',
-      transparent=False, display=False, run_povray=True)
+      transparent=False, run_povray=True)
