@@ -3,7 +3,7 @@ from ase.constraints import FixAtoms
 from ase.calculators.emt import EMT
 from ase.neb import NEB
 from ase.optimize import BFGS
-from ase.parallel import rank, size
+from ase.parallel import world
 
 initial = read('initial.traj')
 final = read('final.traj')
@@ -11,7 +11,7 @@ final = read('final.traj')
 constraint = FixAtoms(mask=[atom.tag > 1 for atom in initial])
 
 images = [initial]
-j = rank * 3 // size  # my image number
+j = world.rank * 3 // world.size  # my image number
 for i in range(3):
     image = initial.copy()
     if i == j:
